@@ -40,4 +40,9 @@ class MissingRunId(Exception):
 
 class ConfigurationVersionUploadError(Exception):
     """Error uploading Terraform tar.gz to Configuration Version."""
+    pass
+
+
+class InvalidQueryParam(Exception):
+    """Unsupported value for query parameter."""
     pass
\ No newline at end of file
